import typing

class AutoSARData(object):
    def __init__(self) -> None:
        self.value = None        # 本对象的名字
        self.name = ''           # 本对象的名字
        pass

    def set(self, value:typing.Any):
        '''
        设置本类的值
        子类重写的时候，应该用 typing 或直接类型提示的方式明显的告诉用户入参的类型是什么
        如 int, str, float
        '''
        pass

    def get(self) -> typing.Any:
        '''
        返回本类的值
        子类重写的时候，应该用 typing 或直接类型提示的方式明显的告诉用户 get 的类型是什么
        如 int, str, float
        '''
        pass

    def pack(self) -> typing.Any:
        '''
        打包本对象
        子类继承的时候，应该用用 typing 或者直接类型提示的方式明显的告诉用户 pack 后的数据类型是什么
        子类重写该函数返回的类型根据子类的类型不同，可能是如下类型
        - ZoneSender.ObjIo.SomeipPackage
        - ZoneSender.ObjIo.LinSignal
        - ZoneSender.ObjIo.ZoneSenderObject 的各种子类
        '''

    def unpack(self, obj:typing.Any) -> None:
        '''
        将 ZoneSender.ObjIo 中的各种 obj 对象的值赋值给本对象
        :param obj: 子类继承的时候需要使用 typing 或直接类型提示的方式提示输入的类型
        调用该函数后，就可以在后面通过 . 的方式获取该对象成员变量的值
        如果解包失败，要 raise Error
        '''
        raise ValueError("未实现")


import copy
import ctypes
import random
import sys
import time
import typing
import uuid
import enum
import json
import dataclasses
import orjson
from pathlib import Path

from .BlfIoObjs import *


def BlfObjFromBytes(data:bytes) -> BlfIoStruct:
    obj_type_ = data[0]
    try:
        d_ = orjson.loads(data[1:])
    except:
        return BlfIoStruct()
    try:
        del d_['_blfObjType']
    except:
        pass
    
    if (obj_type_ == BLF_ObjectType.CAN_FD_MESSAGE):
        return CanFdMessagePy(**d_)
    elif (obj_type_ == BLF_ObjectType.CAN_FD_MESSAGE_64):
        return CanFdMessage64Py(**d_)
    elif (obj_type_ == BLF_ObjectType.CAN_MESSAGE):
        return CanMessagePy(**d_)
    elif (obj_type_ == BLF_ObjectType.CAN_MESSAGE2):
        return CanMessage2Py(**d_)
    elif (obj_type_ == BLF_ObjectType.LIN_MESSAGE):
        return LinMessagePy(**d_)
    elif (obj_type_ == BLF_ObjectType.LIN_MESSAGE2):
        return LinMessage2Py(**d_)
    elif (obj_type_ == BLF_ObjectType.ETHERNET_FRAME):
        return EthernetFramePy(**d_)
    elif (obj_type_ == BLF_ObjectType.CAN_I_SIGNAL_I_PDU):
        return CanISignalIPduPy(**d_)
    elif (obj_type_ == BLF_ObjectType.ETH_SOMEIP_SD):
        return SomeIpSDFramePy(**d_)
    elif (obj_type_ == BLF_ObjectType.ETH_SOMEIP):
        return SomeIpFramePy(**d_)
    elif (obj_type_ == BLF_ObjectType.LIN_FRAME):
        return LinFramePy(**d_)
    else:
        return BlfIoStruct()

class BlfIo(object):
    def __init__(self, dll_path: str = '') -> None:
        if (dll_path == ''):
            dll_path = str(Path(__file__).absolute().parent / 'blf_io_export.dll')
        self._dll_blf_io_export = ctypes.cdll.LoadLibrary(dll_path)

        # 变量 >>>>>>>>>>>>>>
        # Dll Variable >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
        # Header 结构体 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
        self.OBJECT_HEADER_PY_REPLAY = ctypes.POINTER(ObjectHeaderPy)
        self.P_OBJECT_HEADER_PY_REPLAY = self.OBJECT_HEADER_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_OBJECT_HEADER_PY_REPLAY')
        self.OBJECT_HEADER_2_PY_REPLAY = ctypes.POINTER(ObjectHeader2Py)
        self.P_OBJECT_HEADER_2_PY_REPLAY = self.OBJECT_HEADER_2_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_OBJECT_HEADER_2_PY_REPLAY')

        # Replay 相关结构体 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
        self.CAN_FD_MESSAGE_PY_REPLAY = ctypes.POINTER(CanFdMessagePy)
        self.P_CAN_FD_MESSAGE_PY_REPLAY = self.CAN_FD_MESSAGE_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_CAN_FD_MESSAGE_PY_REPLAY')
        self.CAN_FD_MESSAGE_64_PY_REPLAY = ctypes.POINTER(CanFdMessage64Py)
        self.P_CAN_FD_MESSAGE_64_PY_REPLAY = self.CAN_FD_MESSAGE_64_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_CAN_FD_MESSAGE_64_PY_REPLAY')
        self.CAN_MESSAGE_PY_REPLAY = ctypes.POINTER(CanMessagePy)
        self.P_CAN_MESSAGE_PY_REPLAY = self.CAN_MESSAGE_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_CAN_MESSAGE_PY_REPLAY')
        self.CAN_MESSAGE_2_PY_REPLAY = ctypes.POINTER(CanMessage2Py)
        self.P_CAN_MESSAGE_2_PY_REPLAY = self.CAN_MESSAGE_2_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_CAN_MESSAGE_2_PY_REPLAY')
        self.LIN_MESSAGE_PY_REPLAY = ctypes.POINTER(LinMessagePy)
        self.P_LIN_MESSAGE_PY_REPLAY = self.LIN_MESSAGE_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_LIN_MESSAGE_PY_REPLAY')
        self.LIN_MESSAGE_2_PY_REPLAY = ctypes.POINTER(LinMessage2Py)
        self.P_LIN_MESSAGE_2_PY_REPLAY = self.LIN_MESSAGE_2_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_LIN_MESSAGE_2_PY_REPLAY')
        self.ETHERNET_FRAME_PY_REPLAY = ctypes.POINTER(EthernetFramePy)
        self.P_ETHERNET_FRAME_PY_REPLAY = self.ETHERNET_FRAME_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_ETHERNET_FRAME_PY_REPLAY')

        # Log 相关结构体 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
        self.CAN_FD_MESSAGE_PY_LOG = ctypes.POINTER(CanFdMessagePy)
        self.P_CAN_FD_MESSAGE_PY_LOG = self.CAN_FD_MESSAGE_PY_LOG.in_dll(self._dll_blf_io_export, 'P_CAN_FD_MESSAGE_PY_LOG')
        self.CAN_FD_MESSAGE_64_PY_LOG = ctypes.POINTER(CanFdMessage64Py)
        self.P_CAN_FD_MESSAGE_64_PY_LOG = self.CAN_FD_MESSAGE_64_PY_LOG.in_dll(self._dll_blf_io_export, 'P_CAN_FD_MESSAGE_64_PY_LOG')
        self.CAN_MESSAGE_PY_LOG = ctypes.POINTER(CanMessagePy)
        self.P_CAN_MESSAGE_PY_LOG = self.CAN_MESSAGE_PY_LOG.in_dll(self._dll_blf_io_export, 'P_CAN_MESSAGE_PY_LOG')
        self.CAN_MESSAGE_PY_2_LOG = ctypes.POINTER(CanMessage2Py)
        self.P_CAN_MESSAGE_2_PY_LOG = self.CAN_MESSAGE_PY_2_LOG.in_dll(self._dll_blf_io_export, 'P_CAN_MESSAGE_2_PY_LOG')
        self.LIN_MESSAGE_PY_LOG = ctypes.POINTER(LinMessagePy)
        self.P_LIN_MESSAGE_PY_LOG = self.LIN_MESSAGE_PY_LOG.in_dll(self._dll_blf_io_export, 'P_LIN_MESSAGE_PY_LOG')
        self.LIN_MESSAGE_PY_2_LOG = ctypes.POINTER(LinMessage2Py)
        self.P_LIN_MESSAGE_2_PY_LOG = self.LIN_MESSAGE_PY_2_LOG.in_dll(self._dll_blf_io_export, 'P_LIN_MESSAGE_2_PY_LOG')
        self.ETHERNET_FRAME_PY_LOG = ctypes.POINTER(EthernetFramePy)
        self.P_ETHERNET_FRAME_PY_LOG = self.ETHERNET_FRAME_PY_LOG.in_dll(self._dll_blf_io_export, 'P_ETHERNET_FRAME_PY_LOG')

        # 变量 <<<<<<<<<<<<<

        # Functions >>>>>>>>>>>>>>>>>>>>>>>>>
        self._dllFuncOpenLogFile = self._dll_blf_io_export.OpenLogFile
        self._dllFuncOpenLogFile.argtypes = [ctypes.c_char_p]
        self._dllFuncOpenLogFile.restype = ctypes.c_uint8

        self._dllFuncCloseLogFile = self._dll_blf_io_export.CloseLogFile
        self._dllFuncCloseLogFile.argtypes = [ctypes.c_char_p]
        self._dllFuncCloseLogFile.restype = ctypes.c_uint8

        self._dllFuncGetBlfLogInfos = self._dll_blf_io_export.GetBlfLogInfos
        self._dllFuncGetBlfLogInfos.argtypes = [ctypes.POINTER(BlfLogInfo), ctypes.POINTER(ctypes.c_uint8)]
        self._dllFuncGetBlfLogInfos.restype = ctypes.c_uint8

        self._dllFuncLogNext = self._dll_blf_io_export.LogNext
        self._dllFuncLogNext.argtypes = [ctypes.c_char_p, ctypes.c_uint32, ctypes.c_uint64]
        self._dllFuncLogNext.restype = ctypes.c_uint8
    
        self._dllFuncOpenReplayFile = self._dll_blf_io_export.OpenReplayFile
        self._dllFuncOpenReplayFile.argtypes = [ctypes.c_char_p]
        self._dllFuncOpenReplayFile.restype = ctypes.c_uint8

        self._dllFuncCloseReplayFile = self._dll_blf_io_export.CloseReplayFile
        self._dllFuncCloseReplayFile.argtypes = [ctypes.c_char_p]
        self._dllFuncCloseReplayFile.restype = ctypes.c_uint8

        self._dllFuncReplayNext = self._dll_blf_io_export.ReplayNext
        self._dllFuncReplayNext.argtypes = [ctypes.c_char_p, ctypes.POINTER(ctypes.c_uint32), ctypes.POINTER(ctypes.c_uint32)]
        self._dllFuncReplayNext.restype = ctypes.c_uint8
        # Functions <<<<<<<<<<<<<<<<<<<<<<<<
    
    def OpenLogFile(self, file_path: str) -> int:
        res_ = self._dllFuncOpenLogFile((file_path.encode('utf-8')))
        return res_

    def CloseLogFile(self, file_path: str) -> int:
        res_ = self._dllFuncCloseLogFile((file_path.encode('utf-8')))
        return res_

    def LogNext(self, file_path: str, obj: 'BlfIoStruct', time_stamp_ns: int) -> int:
        if (isinstance(obj, CanFdMessagePy)):
            obj.channel += 1
            self.P_CAN_FD_MESSAGE_PY_LOG.contents = obj
            return self._dllFuncLogNext(file_path.encode('utf-8'), ctypes.c_uint32(BLF_ObjectType.CAN_FD_MESSAGE), ctypes.c_uint64(time_stamp_ns))
        elif (isinstance(obj, CanFdMessage64Py)):
            obj.channel += 1
            self.P_CAN_FD_MESSAGE_64_PY_LOG.contents = obj
            return self._dllFuncLogNext(file_path.encode('utf-8'), ctypes.c_uint32(BLF_ObjectType.CAN_FD_MESSAGE_64), ctypes.c_uint64(time_stamp_ns))
        elif (isinstance(obj, CanMessagePy)):
            obj.channel += 1
            self.P_CAN_MESSAGE_PY_LOG.contents = obj
            return self._dllFuncLogNext(file_path.encode('utf-8'), ctypes.c_uint32(BLF_ObjectType.CAN_MESSAGE), ctypes.c_uint64(time_stamp_ns))
        elif (isinstance(obj, CanMessage2Py)):
            obj.channel += 1
            self.P_CAN_MESSAGE_2_PY_LOG.contents = obj
            return self._dllFuncLogNext(file_path.encode('utf-8'), ctypes.c_uint32(BLF_ObjectType.CAN_MESSAGE2), ctypes.c_uint64(time_stamp_ns))
        elif (isinstance(obj, LinMessagePy)):
            obj.channel += 1
            self.P_LIN_MESSAGE_PY_LOG.contents = obj
            return self._dllFuncLogNext(file_path.encode('utf-8'), ctypes.c_uint32(BLF_ObjectType.LIN_MESSAGE), ctypes.c_uint64(time_stamp_ns))
        elif (isinstance(obj, LinMessage2Py)):
            self.P_LIN_MESSAGE_2_PY_LOG.contents = obj
            return self._dllFuncLogNext(file_path.encode('utf-8'), ctypes.c_uint32(BLF_ObjectType.LIN_MESSAGE2), ctypes.c_uint64(time_stamp_ns))
        elif (isinstance(obj, EthernetFramePy)):
            self.P_ETHERNET_FRAME_PY_LOG.contents = obj
            return self._dllFuncLogNext(file_path.encode('utf-8'), ctypes.c_uint32(BLF_ObjectType.ETHERNET_FRAME), ctypes.c_uint64(time_stamp_ns))
        return 10

    def OpenReplayFile(self, file_path: str) -> int:
        res_ = self._dllFuncOpenReplayFile(file_path.encode('utf-8'))
        return res_
    
    def CloseReplayFile(self, file_path: str) -> int:
        return self._dllFuncCloseReplayFile(file_path.encode('utf-8'))
    
    def ReplayNext(self, file_path: str) -> typing.Tuple[int, int, int, BlfIoStruct]:
        '''
        回放下一个报文
        :return:[0]int 是否读取成功
            - 0: 读取成功
            - 1: 文件损坏
            - 2: 下一条报文损坏
            - 3: 下一条报文是空指针
            - 4: 没有打开的文件

        :return:[1]int 时间戳

        :return:[2]int 时间戳类型
            - 0: 未知
            - 1: ms
            - 2: ns
        
        :return:[3]BlfIoStruct 下一个数据，可能为如下类型
            - CanFdMessagePy
            - CanFdMessage64Py
            - CanMessagePy
            - Canmessage2Py
            - LinMessagePy
            - LinMessage2Py
            - EthernetFramePy
        '''
        header_type_ = ctypes.c_uint32()    # 头类型
        obj_type_ = ctypes.c_uint32()    # 对象类型
        time_stamp_ = 0    # 时间戳数据
        time_stamp_type_ = 0    # 时间戳类型
        obj_ = BlfIoStruct()    # 返回的数据对象
        
        res_ = self._dllFuncReplayNext(file_path.encode('utf-8'), ctypes.pointer(header_type_), ctypes.pointer(obj_type_))
        
        if (not (res_ == 0)):
            # 读取失败
            return res_, 0, 0, BlfIoStruct()

        # 检查 object_type
        if (header_type_.value == 1):
            # ObjectHeader
            time_stamp_ = self.P_OBJECT_HEADER_PY_REPLAY.contents.objectTimeStamp
            time_stamp_type_ = self.P_OBJECT_HEADER_PY_REPLAY.contents.objectFlags
        elif (header_type_.value == 2):
            # ObjectHeader2
            time_stamp_ = self.P_OBJECT_HEADER_2_PY_REPLAY.contents.objectTimeStamp
            time_stamp_type_ = self.P_OBJECT_HEADER_2_PY_REPLAY.contents.objectFlags

        if (obj_type_.value == BLF_ObjectType.CAN_FD_MESSAGE):
            # obj_ = copy.deepcopy(self.P_CAN_FD_MESSAGE_PY_REPLAY.contents)
            obj_ = self.P_CAN_FD_MESSAGE_PY_REPLAY.contents
            obj_._blfObjType = BLF_ObjectType.CAN_FD_MESSAGE

        elif (obj_type_.value == BLF_ObjectType.CAN_FD_MESSAGE_64):
            # obj_ = copy.deepcopy(self.P_CAN_FD_MESSAGE_64_PY_REPLAY.contents)
            obj_ = self.P_CAN_FD_MESSAGE_64_PY_REPLAY.contents
            obj_._blfObjType = BLF_ObjectType.CAN_FD_MESSAGE_64

        elif (obj_type_.value == BLF_ObjectType.CAN_MESSAGE):
            # obj_ = copy.deepcopy(self.P_CAN_MESSAGE_PY_REPLAY.contents)
            obj_ = self.P_CAN_MESSAGE_PY_REPLAY.contents
            obj_._blfObjType = BLF_ObjectType.CAN_MESSAGE

        elif (obj_type_.value == BLF_ObjectType.CAN_MESSAGE2):
            # obj_ = copy.deepcopy(self.P_CAN_MESSAGE_2_PY_REPLAY.contents)
            obj_ = self.P_CAN_MESSAGE_2_PY_REPLAY.contents
            obj_._blfObjType = BLF_ObjectType.CAN_MESSAGE2

        elif (obj_type_.value == BLF_ObjectType.LIN_MESSAGE):
            # obj_ = copy.deepcopy(self.P_LIN_MESSAGE_PY_REPLAY.contents)
            obj_ = self.P_LIN_MESSAGE_PY_REPLAY.contents
            obj_._blfObjType = BLF_ObjectType.LIN_MESSAGE

        elif (obj_type_.value == BLF_ObjectType.LIN_MESSAGE2):
            # obj_ = copy.deepcopy(self.P_LIN_MESSAGE_2_PY_REPLAY.contents)
            obj_ = self.P_LIN_MESSAGE_2_PY_REPLAY.contents
            obj_._blfObjType = BLF_ObjectType.LIN_MESSAGE2

        elif (obj_type_.value == BLF_ObjectType.ETHERNET_FRAME):
            # obj_ = copy.deepcopy(self.P_ETHERNET_FRAME_PY_REPLAY.contents)
            obj_ = self.P_ETHERNET_FRAME_PY_REPLAY.contents
            obj_._blfObjType = BLF_ObjectType.ETHERNET_FRAME
            
        return res_, time_stamp_, time_stamp_type_, obj_

    def GetBlfLogInfos(self) -> typing.List[BlfLogInfo]:
        '''
        获取当前正在记录的 Blf 信息
        '''
        entry_list_ = []
        blf_io_for_log_array_ = (BlfLogInfo * 256)(*entry_list_)
        len_ = ctypes.c_uint8()
        return_l_ = []

        self._dllFuncGetBlfLogInfos(blf_io_for_log_array_, ctypes.pointer(len_))
        for i_ in range(int.from_bytes(len_, byteorder='big', signed=True)):
            return_l_.append(blf_io_for_log_array_[i_])
        return return_l_

# class BlfIoBack(object):
#     def __init__(self, dll_path: str = '') -> None:
#         '''
#         blfIO 操作库
#         :param dll_path:str dll 的路径，默认为本文件通路径下的 blf_io_export.dll
#         '''
#         if (dll_path == ''):
#             # 如果是默认的 dll 路径
#             dll_path = str(Path(__file__).absolute().parent / 'blf_io_export.dll')
#         # print(dll_path)
        
        
#         # 类内变量 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#         self._log_start_ns = 0


#         # Dll Obj >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#         self._dll_blf_io_export = ctypes.cdll.LoadLibrary(dll_path)


#         # Dll Function >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#         self._dllFuncOpenReplayFile = self._dll_blf_io_export.OpenReplayFile
#         self._dllFuncOpenReplayFile.argtypes = [ctypes.c_char_p]
#         self._dllFuncOpenReplayFile.restype = ctypes.c_int

#         self._dllFuncCloseReplayFile = self._dll_blf_io_export.CloseReplayFile
#         self._dllFuncCloseReplayFile.restype = ctypes.c_int

#         self._dllFuncReplayNext = self._dll_blf_io_export.ReplayNext
#         # p_header_type, p_obj_type, p_time_stamp, p_time_stamp_type
#         self._dllFuncReplayNext.argtypes = [ctypes.POINTER(ctypes.c_uint32), ctypes.POINTER(ctypes.c_uint32)]
#         self._dllFuncReplayNext.restype = ctypes.c_int

#         self._dllFuncOpenLogFile = self._dll_blf_io_export.OpenLogFile
#         self._dllFuncOpenLogFile.argtypes = [ctypes.c_char_p]
#         self._dllFuncOpenLogFile.restype = ctypes.c_int

#         self._dllFuncCloseLogFile = self._dll_blf_io_export.CloseLogFile
#         self._dllFuncCloseLogFile.restype = ctypes.c_int

#         self._dllFuncLogNext = self._dll_blf_io_export.LogNext
#         self._dllFuncLogNext.argtypes = [ctypes.c_uint32, ctypes.c_uint64]
#         self._dllFuncLogNext.restype = ctypes.c_int
        

#         # Dll Variable >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#         # Header 结构体 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#         self.OBJECT_HEADER_PY_REPLAY = ctypes.POINTER(ObjectHeaderPy)
#         self.P_OBJECT_HEADER_PY_REPLAY = self.OBJECT_HEADER_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_OBJECT_HEADER_PY_REPLAY')
#         self.OBJECT_HEADER_2_PY_REPLAY = ctypes.POINTER(ObjectHeader2Py)
#         self.P_OBJECT_HEADER_2_PY_REPLAY = self.OBJECT_HEADER_2_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_OBJECT_HEADER_2_PY_REPLAY')

#         # Replay 相关结构体 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#         self.CAN_FD_MESSAGE_PY_REPLAY = ctypes.POINTER(CanFdMessagePy)
#         self.P_CAN_FD_MESSAGE_PY_REPLAY = self.CAN_FD_MESSAGE_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_CAN_FD_MESSAGE_PY_REPLAY')
#         self.CAN_FD_MESSAGE_64_PY_REPLAY = ctypes.POINTER(CanFdMessage64Py)
#         self.P_CAN_FD_MESSAGE_64_PY_REPLAY = self.CAN_FD_MESSAGE_64_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_CAN_FD_MESSAGE_64_PY_REPLAY')
#         self.CAN_MESSAGE_PY_REPLAY = ctypes.POINTER(CanMessagePy)
#         self.P_CAN_MESSAGE_PY_REPLAY = self.CAN_MESSAGE_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_CAN_MESSAGE_PY_REPLAY')
#         self.CAN_MESSAGE_2_PY_REPLAY = ctypes.POINTER(CanMessage2Py)
#         self.P_CAN_MESSAGE_2_PY_REPLAY = self.CAN_MESSAGE_2_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_CAN_MESSAGE_2_PY_REPLAY')
#         self.LIN_MESSAGE_PY_REPLAY = ctypes.POINTER(LinMessagePy)
#         self.P_LIN_MESSAGE_PY_REPLAY = self.LIN_MESSAGE_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_LIN_MESSAGE_PY_REPLAY')
#         self.LIN_MESSAGE_2_PY_REPLAY = ctypes.POINTER(LinMessage2Py)
#         self.P_LIN_MESSAGE_2_PY_REPLAY = self.LIN_MESSAGE_2_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_LIN_MESSAGE_2_PY_REPLAY')
#         self.ETHERNET_FRAME_PY_REPLAY = ctypes.POINTER(EthernetFramePy)
#         self.P_ETHERNET_FRAME_PY_REPLAY = self.ETHERNET_FRAME_PY_REPLAY.in_dll(self._dll_blf_io_export, 'P_ETHERNET_FRAME_PY_REPLAY')

#         # Log 相关结构体 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#         self.CAN_FD_MESSAGE_PY_LOG = ctypes.POINTER(CanFdMessagePy)
#         self.P_CAN_FD_MESSAGE_PY_LOG = self.CAN_FD_MESSAGE_PY_LOG.in_dll(self._dll_blf_io_export, 'P_CAN_FD_MESSAGE_PY_LOG')
#         self.CAN_FD_MESSAGE_64_PY_LOG = ctypes.POINTER(CanFdMessage64Py)
#         self.P_CAN_FD_MESSAGE_64_PY_LOG = self.CAN_FD_MESSAGE_64_PY_LOG.in_dll(self._dll_blf_io_export, 'P_CAN_FD_MESSAGE_64_PY_LOG')
#         self.CAN_MESSAGE_PY_LOG = ctypes.POINTER(CanMessagePy)
#         self.P_CAN_MESSAGE_PY_LOG = self.CAN_MESSAGE_PY_LOG.in_dll(self._dll_blf_io_export, 'P_CAN_MESSAGE_PY_LOG')
#         self.CAN_MESSAGE_PY_2_LOG = ctypes.POINTER(CanMessage2Py)
#         self.P_CAN_MESSAGE_2_PY_LOG = self.CAN_MESSAGE_PY_2_LOG.in_dll(self._dll_blf_io_export, 'P_CAN_MESSAGE_2_PY_LOG')
#         self.LIN_MESSAGE_PY_LOG = ctypes.POINTER(LinMessagePy)
#         self.P_LIN_MESSAGE_PY_LOG = self.LIN_MESSAGE_PY_LOG.in_dll(self._dll_blf_io_export, 'P_LIN_MESSAGE_PY_LOG')
#         self.LIN_MESSAGE_PY_2_LOG = ctypes.POINTER(LinMessage2Py)
#         self.P_LIN_MESSAGE_2_PY_LOG = self.LIN_MESSAGE_PY_2_LOG.in_dll(self._dll_blf_io_export, 'P_LIN_MESSAGE_2_PY_LOG')
#         self.ETHERNET_FRAME_PY_LOG = ctypes.POINTER(EthernetFramePy)
#         self.P_ETHERNET_FRAME_PY_LOG = self.ETHERNET_FRAME_PY_LOG.in_dll(self._dll_blf_io_export, 'P_ETHERNET_FRAME_PY_LOG')
    
#     def OpenReplayFile(self, path: str) -> int:
#         '''
#         打开一个回放文件
#         :param path: str 回放文件的路径
#         :return: int
#             - 0: 打开成功
#             - 1: 打开失败 
#             - 2: 文件不存在
#         '''
#         if (not Path(path).is_file()):
#             return 1
#         if (not Path(path).exists()):
#             return 2
#         res_ = self._dllFuncOpenReplayFile(path.encode('utf-8'))
#         # print(type(res_))
#         return res_

#     def CloseReplyFile(self) -> int:
#         '''
#         关闭当前回放的文件
#         :return: int\n
#             - 0: 关闭成功\n
#             - 1: 没有打开的回放文件
#         '''
#         return self._dllFuncCloseReplayFile()

#     def ReplayNext(self) -> typing.Tuple[int, int, int, BlfIoStruct]:
#         '''
#         回放下一个报文
#         :return:[0]int 是否读取成功
#             - 0: 读取成功
#             - 1: 文件损坏
#             - 2: 下一条报文损坏
#             - 3: 下一条报文是空指针
#             - 4: 没有打开的文件
#         :return:[1]int 时间戳
#         :return:[2]int 时间戳类型
#             - 0: 未知
#             - 1: ms
#             - 2: ns
#         :return:[3]BlfIoStruct 下一个数据，可能为如下类型
#             - CanFdMessagePy
#             - CanFdMessage64Py
#             - CanMessagePy
#             - Canmessage2Py
#             - LinMessagePy
#             - LinMessage2Py
#             - EthernetFramePy
#         '''
#         header_type_ = ctypes.c_uint32()    # 头类型
#         obj_type_ = ctypes.c_uint32()    # 对象类型
#         time_stamp_ = 0    # 时间戳数据
#         time_stamp_type_ = 0    # 时间戳类型
#         obj_ = BlfIoStruct()    # 返回的数据对象
        
#         res_ = self._dllFuncReplayNext(ctypes.pointer(header_type_), ctypes.pointer(obj_type_))
        
#         if (not (res_ == 0)):
#             # 读取失败
#             return res_, 0, 0, BlfIoStruct()

#         # 检查 object_type
#         # print('header_type = {0}'.format(header_type_.value))
#         if (header_type_.value == 1):
#             # ObjectHeader
#             time_stamp_ = self.P_OBJECT_HEADER_PY_REPLAY.contents.objectTimeStamp
#             time_stamp_type_ = self.P_OBJECT_HEADER_PY_REPLAY.contents.objectFlags
#         elif (header_type_.value == 2):
#             # ObjectHeader2
#             time_stamp_ = self.P_OBJECT_HEADER_2_PY_REPLAY.contents.objectTimeStamp
#             time_stamp_type_ = self.P_OBJECT_HEADER_2_PY_REPLAY.contents.objectFlags

#         if (obj_type_.value == BLF_ObjectType.CAN_FD_MESSAGE):
#             # obj_ = copy.deepcopy(self.P_CAN_FD_MESSAGE_PY_REPLAY.contents)
#             obj_ = self.P_CAN_FD_MESSAGE_PY_REPLAY.contents
#             obj_._blfObjType = BLF_ObjectType.CAN_FD_MESSAGE

#         if (obj_type_.value == BLF_ObjectType.CAN_FD_MESSAGE_64):
#             # obj_ = copy.deepcopy(self.P_CAN_FD_MESSAGE_64_PY_REPLAY.contents)
#             obj_ = self.P_CAN_FD_MESSAGE_64_PY_REPLAY.contents
#             obj_._blfObjType = BLF_ObjectType.CAN_FD_MESSAGE_64

#         if (obj_type_.value == BLF_ObjectType.CAN_MESSAGE):
#             # obj_ = copy.deepcopy(self.P_CAN_MESSAGE_PY_REPLAY.contents)
#             obj_ = self.P_CAN_MESSAGE_PY_REPLAY.contents
#             obj_._blfObjType = BLF_ObjectType.CAN_MESSAGE

#         if (obj_type_.value == BLF_ObjectType.CAN_MESSAGE2):
#             # obj_ = copy.deepcopy(self.P_CAN_MESSAGE_2_PY_REPLAY.contents)
#             obj_ = self.P_CAN_MESSAGE_2_PY_REPLAY.contents
#             obj_._blfObjType = BLF_ObjectType.CAN_MESSAGE2

#         if (obj_type_.value == BLF_ObjectType.LIN_MESSAGE):
#             # obj_ = copy.deepcopy(self.P_LIN_MESSAGE_PY_REPLAY.contents)
#             obj_ = self.P_LIN_MESSAGE_PY_REPLAY.contents
#             obj_._blfObjType = BLF_ObjectType.LIN_MESSAGE

#         if (obj_type_.value == BLF_ObjectType.LIN_MESSAGE2):
#             # obj_ = copy.deepcopy(self.P_LIN_MESSAGE_2_PY_REPLAY.contents)
#             obj_ = self.P_LIN_MESSAGE_2_PY_REPLAY.contents
#             obj_._blfObjType = BLF_ObjectType.LIN_MESSAGE2

#         if (obj_type_.value == BLF_ObjectType.ETHERNET_FRAME):
#             # obj_ = copy.deepcopy(self.P_ETHERNET_FRAME_PY_REPLAY.contents)
#             obj_ = self.P_ETHERNET_FRAME_PY_REPLAY.contents
#             obj_._blfObjType = BLF_ObjectType.ETHERNET_FRAME
            
#         return res_, time_stamp_, time_stamp_type_, obj_

#     def OpenLogFile(self, path: str) -> int:
#         '''
#         创建一个记录文件
#         :param path: str 回放文件的路径
#         :return: int\n
#             - 0: 打开成功\n
#             - 1: 已经有打开的文件了\n
#             - 2: 打开文件失败 
#         '''
#         res_ = self._dllFuncOpenLogFile(path.encode('utf-8'))
#         # print(type(res_))
#         if (res_ == 0):
#             self._log_start_ns = time.time_ns()
#         return res_

#     def CloseLogFile(self) -> int:
#         '''
#         关闭当前的记录文件
#         :return: int\n
#             - 0: 关闭成功\n
#             - 1: 没有打开的回放文件
#         '''
#         return self._dllFuncCloseLogFile()

#     def LogNext(self,obj: 'BlfIoStruct', time_stamp_ns: int = -1) -> int:
#         '''
#         记录一个 Frame
#         :return: int\n
#             - 0: 记录成功\n
#             - 1: 文件未打开\n
#             - 10: 未知的数据结构
#         '''
#         time_stamp_ns_ = time_stamp_ns
#         if (time_stamp_ns_ < 0):
#             time_stamp_ns_ = time.time_ns() - self._log_start_ns
#         else:
#             time_stamp_ns_ = time_stamp_ns_ >> 16
#         if (isinstance(obj, CanFdMessagePy)):
#             self.P_CAN_FD_MESSAGE_PY_LOG.contents = obj
#             return self._dllFuncLogNext(ctypes.c_uint32(BLF_ObjectType.CAN_FD_MESSAGE), ctypes.c_uint64(time_stamp_ns_))
#         if (isinstance(obj, CanFdMessage64Py)):
#             self.P_CAN_FD_MESSAGE_64_PY_LOG.contents = obj
#             return self._dllFuncLogNext(ctypes.c_uint32(BLF_ObjectType.CAN_FD_MESSAGE_64), ctypes.c_uint64(time_stamp_ns_))
#         if (isinstance(obj, CanMessagePy)):
#             self.P_CAN_MESSAGE_PY_LOG.contents = obj
#             return self._dllFuncLogNext(ctypes.c_uint32(BLF_ObjectType.CAN_MESSAGE), ctypes.c_uint64(time_stamp_ns_))
#         if (isinstance(obj, CanMessage2Py)):
#             self.P_CAN_MESSAGE_2_PY_LOG.contents = obj
#             return self._dllFuncLogNext(ctypes.c_uint32(BLF_ObjectType.CAN_MESSAGE2), ctypes.c_uint64(time_stamp_ns_))
#         if (isinstance(obj, LinMessagePy)):
#             self.P_LIN_MESSAGE_PY_LOG.contents = obj
#             return self._dllFuncLogNext(ctypes.c_uint32(BLF_ObjectType.LIN_MESSAGE), ctypes.c_uint64(time_stamp_ns_))
#         if (isinstance(obj, LinMessage2Py)):
#             self.P_LIN_MESSAGE_2_PY_LOG.contents = obj
#             return self._dllFuncLogNext(ctypes.c_uint32(BLF_ObjectType.LIN_MESSAGE2), ctypes.c_uint64(time_stamp_ns_))
#         if (isinstance(obj, EthernetFramePy)):
#             self.P_ETHERNET_FRAME_PY_LOG.contents = obj
#             return self._dllFuncLogNext(ctypes.c_uint32(BLF_ObjectType.ETHERNET_FRAME), ctypes.c_uint64(time_stamp_ns_))
#         return 10



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UdsOnCanTP.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10UdsOnCanTP.proto\x12\nUdsOnCanTP\x1a\x0c\x43ommon.proto\"R\n\tnode_info\x12\x17\n\x0frequest_id_phys\x18\x01 \x01(\x04\x12\x13\n\x0bresponse_id\x18\x02 \x01(\x04\x12\x17\n\x0frequest_id_func\x18\x03 \x01(\x04\"<\n\x0crequest_para\x12\x12\n\nseed_value\x18\x01 \x03(\r\x12\x18\n\x10\x61lgorithm_number\x18\x02 \x01(\r\"#\n\x0ekey_value_list\x12\x11\n\tkey_value\x18\x01 \x03(\r2\x8a\x01\n\nUdsOnCanTP\x12\x34\n\tsubscribe\x12\x15.UdsOnCanTP.node_info\x1a\x0e.Common.result\"\x00\x12\x46\n\x0cgenerate_key\x12\x18.UdsOnCanTP.request_para\x1a\x1a.UdsOnCanTP.key_value_list\"\x00\x62\x06proto3')



_NODE_INFO = DESCRIPTOR.message_types_by_name['node_info']
_REQUEST_PARA = DESCRIPTOR.message_types_by_name['request_para']
_KEY_VALUE_LIST = DESCRIPTOR.message_types_by_name['key_value_list']
node_info = _reflection.GeneratedProtocolMessageType('node_info', (_message.Message,), {
  'DESCRIPTOR' : _NODE_INFO,
  '__module__' : 'UdsOnCanTP_pb2'
  # @@protoc_insertion_point(class_scope:UdsOnCanTP.node_info)
  })
_sym_db.RegisterMessage(node_info)

request_para = _reflection.GeneratedProtocolMessageType('request_para', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST_PARA,
  '__module__' : 'UdsOnCanTP_pb2'
  # @@protoc_insertion_point(class_scope:UdsOnCanTP.request_para)
  })
_sym_db.RegisterMessage(request_para)

key_value_list = _reflection.GeneratedProtocolMessageType('key_value_list', (_message.Message,), {
  'DESCRIPTOR' : _KEY_VALUE_LIST,
  '__module__' : 'UdsOnCanTP_pb2'
  # @@protoc_insertion_point(class_scope:UdsOnCanTP.key_value_list)
  })
_sym_db.RegisterMessage(key_value_list)

_UDSONCANTP = DESCRIPTOR.services_by_name['UdsOnCanTP']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NODE_INFO._serialized_start=46
  _NODE_INFO._serialized_end=128
  _REQUEST_PARA._serialized_start=130
  _REQUEST_PARA._serialized_end=190
  _KEY_VALUE_LIST._serialized_start=192
  _KEY_VALUE_LIST._serialized_end=227
  _UDSONCANTP._serialized_start=230
  _UDSONCANTP._serialized_end=368
# @@protoc_insertion_point(module_scope)



import json
import typing
from typing import Union

import grpc

from . import ZoneSenderData
from .ObjIo import *

from .Protos import TcpIpNode_pb2, TcpIpNode_pb2_grpc



class TcpIpNodeClient(object):
    def __init__(self) -> None:
        """
        TcpIpNode 的客户端
        """
        self._tcpipStub = TcpIpNode_pb2_grpc.TcpIpNodeStub(
            channel=grpc.insecure_channel(
                target='{0}:{1}'
                    .format(
                        ZoneSenderData.TCPIP_STACK_NODE_IP, 
                        ZoneSenderData.TCPIP_STACK_NODE_PORT),
                options = ZoneSenderData.GRPC_OPTIONS
            )
        )

    def Init(self,appBName:str = 'CANoe') -> 'int':
        try:
            res_ = self._tcpipStub.InitTcpIpStack(
                TcpIpNode_pb2.Common__pb2.generic_string(
                    text = appBName,
                )
            )
            print('Init result: {0}, reason: {1}'.format(res_.result, res_.reason))
            return res_.result
        except Exception as e_ :
            print(e_)
            return 1000
    
    def GetVectorPortInfo(self) -> Union['int','list'] :
        try:
            res_ = self._tcpipStub.GetAllVectorPortInfo(
                TcpIpNode_pb2.Common__pb2.empty()
            )
            if res_.result.result == 0 :
                port_list = list()
                for item in res_.all_port :
                    item_dict = {'networkName':item.networkName,
                                 'switchName':item.switchName,
                                 'portName':item.portName,
                                 'portType':item.portType}
                    port_list.append(item_dict)
                return port_list
            else :
                raise Exception(f'{res_.result.reason}')
        except Exception as e_ :
            print(e_)
            return 1000
    
    def OpenVectorPort(self,networkName:str,switchName:str,portName:str,portType:str) :
        try:
            res_ = self._tcpipStub.OpenVectorPort(
                TcpIpNode_pb2.vector_port_info(
                    networkName = networkName,
                    switchName = switchName,
                    portName = portName,
                    portType = portType,
                )
            )
            return res_.result
        except Exception as e_ :
            print(e_)
    
    def Start(self) :
        try:
            res_ = self._tcpipStub.StartTcpIpStack(
                TcpIpNode_pb2.Common__pb2.empty()
            )
            return res_.result
        except Exception as e_ :
            print(e_)
    
    def Stop(self) :
        try:
            res_ = self._tcpipStub.StopTcpIpStack(
                TcpIpNode_pb2.Common__pb2.empty()
            )
            return res_.result
        except Exception as e_ :
            print(e_)



import grpc
from . import ZoneSenderData
from .Protos import UdsOnCanTP_pb2, UdsOnCanTP_pb2_grpc


class CanUdsNodeClient(object):
    def __init__(self):
        self._udsStub = UdsOnCanTP_pb2_grpc.UdsOnCanTPStub(
            channel=grpc.insecure_channel(
                target=f'{ZoneSenderData.CAN_UDS_NODE_IP}:{ZoneSenderData.CAN_UDS_NODE_PORT}',
                options=ZoneSenderData.GRPC_OPTIONS
            )
        )

    def generate_key(self, seed: list, algorithm_number=0x4F):
        try:
            res_ = self._udsStub.generate_key(UdsOnCanTP_pb2.request_para(
                seed_value=seed,
                algorithm_number=algorithm_number,
            ))
            print(f'seed:{seed}, algorithm_number:{algorithm_number}')
            return res_.key_value
        except Exception as e:
            print(e)
            return [0x00, 0x00, 0x00, 0x00]


from .ZoneSenderObject import ZoneSenderObject


class CanDiagMessage(ZoneSenderObject):
    def __init__(self, id: int, cmd: list, dlc=8, is_fd=False):
        super().__init__()
        self.id = id
        self.cmd = cmd
        self.dlc = dlc
        self.is_fd = is_fd



from typing import Union
import grpc
import json
import os

from . import ZoneSenderData
from .ObjIo import *

from .Protos import LinParserNode_pb2, LinParserNode_pb2_grpc


class LinParseNodeClient(object):
    """
    LinParserNode 的客户端
    """

    def __init__(self) -> None:
        self._linDbParserStub = LinParserNode_pb2_grpc.LinParserNodeStub(
            channel=grpc.insecure_channel(
                target='{0}:{1}'
                .format(
                    ZoneSenderData.LIN_PARSERNODE_NODE_IP,
                    ZoneSenderData.LIN_PARSERNODE_NODE_PORT),
                options=ZoneSenderData.GRPC_OPTIONS
            )
        )

    def setChannelConfig(self, appChannel: int, ldfPath: str, linMode: str,
                         txrecv: int = 0, baudrate: int = 0) -> int:
        ''' 添加一个ldf文件到特定的通道上
        :param appChannel: int vector硬件配置上对应的LIN通道 
        :param ldfPath: str ldf文件的路径
        :param linMode: str 该通道的模式，支持Master,Slave 
        :param txrecv: int 默认全接收，0为全接收，1为接收收到的报文，2为接收发送的报文
        :param baudrate: int 默认19200,波特率
        :return: int\n
            - 0: 成功\n
            - 1: 配置失败\n
            - 1000: error\n
        '''
        try:
            res_ = self._linDbParserStub.SetChannelConfig(
                LinParserNode_pb2.lin_channel_config(
                    ldf_path=ldfPath,
                    lin_mode=linMode,
                    txrecv=txrecv,
                    baudrate=baudrate,
                    lin_channel=appChannel,
                )
            )
            print('setChannelConfig result: {0}, reason: {0}'.format(res_.result, res_.reason))
            return res_.result
        except Exception as e_:
            print(e_)
            return 1000

    def getLdfJson(self) -> Union[dict, int]:
        ''' 获取配置的ldf，并返回解析后的ldf
        :return: dict,int\n
            - dict: 成功\n
            - 1000: error\n
        '''
        try:
            res_ = self._linDbParserStub.GetLdfJsonTree(
                LinParserNode_pb2.Common__pb2.empty()
            )
            print('getLdfJson result: {0}, reason: {0}'.format(res_.result, res_.reason))
            if res_.result == 0:
                return json.loads(res_.json_data)
            else:
                raise Exception(f'{res_.reason}')
        except Exception as e_:
            print(e_)
            return 1000

    def clearChannelConfig(self) -> int:
        ''' 清空所有已配置的ldf文件
        :return: int\n
            - 0: 成功\n
            - 1000: error\n
        '''
        try:
            res_ = self._linDbParserStub.ClearDbfile(
                LinParserNode_pb2.Common__pb2.empty()
            )
            return res_.result
        except Exception as e_:
            print(e_)
            return 1000

    def clearSubscribe(self):
        ''' 清空所有的订阅
        :return: int\n
            - 0: 成功\n
            - 1000: error\n
        '''
        try:
            res_ = self._linDbParserStub.ClearSubscribe(
                LinParserNode_pb2.Common__pb2.empty()
            )
            print('清除所有 LinParser 的订阅 result: {0}, reason: {0}'.format(res_.result, res_.reason))
            return res_.result
        except Exception as e_:
            print(e_)
            return 1000

    def setFrameSimulation(self, channel: int, frame: Union[int, str], simu: bool) -> int:
        ''' 设置LIN报文仿真
        :param channel: int vector硬件配置上对应的LIN通道
        :param frame: int or str LIN报文的名字或者ID
        :param simu: bool True为仿真，False为关闭仿真
        :return: int\n
            - 0: 成功\n
            - 1: 未找到指定报文
            - 1000: error\n
        '''
        try:
            if isinstance(frame, str):
                linframe = LinParserNode_pb2.lin_frame_config(
                    frame_name=frame,
                    channel=channel,
                    simu=simu,
                )
            elif isinstance(frame, int):
                linframe = LinParserNode_pb2.lin_frame_config(
                    frame_id=frame,
                    channel=channel,
                    simu=simu,
                )
            else:
                print(f'frame type unsupport,input type is {type(frame)}')
                return 1000
            res_ = self._linDbParserStub.SetFrameSimulation(linframe)
            print('setFrameSimulation result: {0}, reason: {0}'.format(res_.result, res_.reason))
            return res_.result
        except Exception as e_:
            print(e_)
            return 1000

    def setNodeSimulation(self, channel: int, Node: str, simu: bool) -> int:
        ''' 设置LIN节点仿真
        :param channel: int vector硬件配置上对应的LIN通道
        :param Node: str LIN节点的名字
        :param simu: bool True为仿真，False为关闭仿真
        :return: int\n
            - 0: 成功\n
            - 1: 未找到指定的节点
            - 1000: error\n
        '''
        try:
            if isinstance(Node, str):
                res_ = self._linDbParserStub.SetNodeSimulation(
                    LinParserNode_pb2.lin_node_config(
                        node_name=Node,
                        channel=channel,
                        simu=simu,
                    )
                )
            else:
                print(f'Node type unsupport,input type is {type(Node)}')
                return 1000
            print('setNodeSimulation result: {0}, reason: {0}'.format(res_.result, res_.reason))
            return res_.result
        except Exception as e_:
            print(e_)
            return 1000

    def ConvertLinDbToPy(self, src_file: str, dst_file: str, channel: int) -> int:
        ''' 把LinDb转换Pthon
        :param src_file: str ldf/json文件的路径
        :param dst_file: str 转换后python的地址
        :return: int\n
            - 0: 成功\n
            - 1: 配置失败\n
            - 1000: error\n
        '''
        try:
            # 如果是相对路径转换为绝对路径
            if not os.path.isabs(src_file):
                src_file = os.path.abspath(src_file)
            # 如果是相对路径转换为绝对路径
            if not os.path.isabs(dst_file):
                dst_file = os.path.abspath(dst_file)

            res_ = self._linDbParserStub.ConvertLinDbToPy(
                LinParserNode_pb2.convert_input(
                    src_file=src_file,
                    dst_file=dst_file,
                    channel=channel
                )
            )
            print('ConvertLinDbToPy result: {0}, reason: {1}'.format(res_.result, res_.reason))
            return res_.result
        except Exception as e_:
            print(e_)
            return 1000

    def ConvertLinDbToJson(self, src_file: str, dst_file: str, channel: int) -> int:
        ''' 把LinDb转换Json
        :param src_file: str ldf/json文件的路径
        :param dst_file: str 转换后python的地址
        :parm channel: int 通道
        :return: int\n
            - 0: 成功\n
            - 1: 配置失败\n
            - 1000: error\n
        '''
        try:
            # 如果是相对路径转换为绝对路径
            if not os.path.isabs(src_file):
                src_file = os.path.abspath(src_file)
            # 如果是相对路径转换为绝对路径
            if not os.path.isabs(dst_file):
                dst_file = os.path.abspath(dst_file)

            res_ = self._linDbParserStub.ConvertLinDbToJson(
                LinParserNode_pb2.convert_input(
                    src_file=src_file,
                    dst_file=dst_file,
                    channel=channel
                )
            )
            print('ConvertLinJsonToPy result: {0}, reason: {1}'.format(res_.result, res_.reason))
            return res_.result
        except Exception as e_:
            print(e_)
            return 1000



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import Common_pb2 as Common__pb2
from . import TcpIpNode_pb2 as TcpIpNode__pb2


class TcpIpNodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InitTcpIpStack = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/InitTcpIpStack',
                request_serializer=Common__pb2.generic_string.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.StartTcpIpStack = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/StartTcpIpStack',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.StopTcpIpStack = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/StopTcpIpStack',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.GetAllVectorPortInfo = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/GetAllVectorPortInfo',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=TcpIpNode__pb2.vector_all_port_info.FromString,
                )
        self.OpenVectorPort = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/OpenVectorPort',
                request_serializer=TcpIpNode__pb2.vector_port_info.SerializeToString,
                response_deserializer=TcpIpNode__pb2.openPort_result.FromString,
                )
        self.AddProtoPortInfo = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/AddProtoPortInfo',
                request_serializer=TcpIpNode__pb2.proto_port_info.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.CreatZoneIface = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/CreatZoneIface',
                request_serializer=TcpIpNode__pb2.zone_ifcae_info.SerializeToString,
                response_deserializer=TcpIpNode__pb2.openPort_result.FromString,
                )
        self.ZoneIfaceUp = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/ZoneIfaceUp',
                request_serializer=Common__pb2.generic_int.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.ZoneIfaceDown = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/ZoneIfaceDown',
                request_serializer=Common__pb2.generic_int.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.ZoneIfaceRemove = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/ZoneIfaceRemove',
                request_serializer=Common__pb2.generic_int.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.ZoneIfaceAddGroupAddress = channel.unary_unary(
                '/TcpIpNode.TcpIpNode/ZoneIfaceAddGroupAddress',
                request_serializer=TcpIpNode__pb2.groupAddress.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )


class TcpIpNodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def InitTcpIpStack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartTcpIpStack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopTcpIpStack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllVectorPortInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenVectorPort(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddProtoPortInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatZoneIface(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZoneIfaceUp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZoneIfaceDown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZoneIfaceRemove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZoneIfaceAddGroupAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TcpIpNodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InitTcpIpStack': grpc.unary_unary_rpc_method_handler(
                    servicer.InitTcpIpStack,
                    request_deserializer=Common__pb2.generic_string.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'StartTcpIpStack': grpc.unary_unary_rpc_method_handler(
                    servicer.StartTcpIpStack,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'StopTcpIpStack': grpc.unary_unary_rpc_method_handler(
                    servicer.StopTcpIpStack,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'GetAllVectorPortInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllVectorPortInfo,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=TcpIpNode__pb2.vector_all_port_info.SerializeToString,
            ),
            'OpenVectorPort': grpc.unary_unary_rpc_method_handler(
                    servicer.OpenVectorPort,
                    request_deserializer=TcpIpNode__pb2.vector_port_info.FromString,
                    response_serializer=TcpIpNode__pb2.openPort_result.SerializeToString,
            ),
            'AddProtoPortInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.AddProtoPortInfo,
                    request_deserializer=TcpIpNode__pb2.proto_port_info.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'CreatZoneIface': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatZoneIface,
                    request_deserializer=TcpIpNode__pb2.zone_ifcae_info.FromString,
                    response_serializer=TcpIpNode__pb2.openPort_result.SerializeToString,
            ),
            'ZoneIfaceUp': grpc.unary_unary_rpc_method_handler(
                    servicer.ZoneIfaceUp,
                    request_deserializer=Common__pb2.generic_int.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'ZoneIfaceDown': grpc.unary_unary_rpc_method_handler(
                    servicer.ZoneIfaceDown,
                    request_deserializer=Common__pb2.generic_int.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'ZoneIfaceRemove': grpc.unary_unary_rpc_method_handler(
                    servicer.ZoneIfaceRemove,
                    request_deserializer=Common__pb2.generic_int.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'ZoneIfaceAddGroupAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.ZoneIfaceAddGroupAddress,
                    request_deserializer=TcpIpNode__pb2.groupAddress.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'TcpIpNode.TcpIpNode', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TcpIpNode(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def InitTcpIpStack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/InitTcpIpStack',
            Common__pb2.generic_string.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartTcpIpStack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/StartTcpIpStack',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopTcpIpStack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/StopTcpIpStack',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllVectorPortInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/GetAllVectorPortInfo',
            Common__pb2.empty.SerializeToString,
            TcpIpNode__pb2.vector_all_port_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OpenVectorPort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/OpenVectorPort',
            TcpIpNode__pb2.vector_port_info.SerializeToString,
            TcpIpNode__pb2.openPort_result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddProtoPortInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/AddProtoPortInfo',
            TcpIpNode__pb2.proto_port_info.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatZoneIface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/CreatZoneIface',
            TcpIpNode__pb2.zone_ifcae_info.SerializeToString,
            TcpIpNode__pb2.openPort_result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ZoneIfaceUp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/ZoneIfaceUp',
            Common__pb2.generic_int.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ZoneIfaceDown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/ZoneIfaceDown',
            Common__pb2.generic_int.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ZoneIfaceRemove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/ZoneIfaceRemove',
            Common__pb2.generic_int.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ZoneIfaceAddGroupAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/TcpIpNode.TcpIpNode/ZoneIfaceAddGroupAddress',
            TcpIpNode__pb2.groupAddress.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import Common_pb2 as Common__pb2
from . import ProcessNode_pb2 as ProcessNode__pb2


class ProcessNodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetProcessInfo = channel.unary_unary(
                '/ProcessNode.ProcessNode/GetProcessInfo',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=ProcessNode__pb2.return_info.FromString,
                )
        self.GetVersionInfo = channel.unary_unary(
                '/ProcessNode.ProcessNode/GetVersionInfo',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=ProcessNode__pb2.return_info.FromString,
                )


class ProcessNodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetProcessInfo(self, request, context):
        """复位 LinStackNode
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersionInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProcessNodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetProcessInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProcessInfo,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=ProcessNode__pb2.return_info.SerializeToString,
            ),
            'GetVersionInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersionInfo,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=ProcessNode__pb2.return_info.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ProcessNode.ProcessNode', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProcessNode(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetProcessInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ProcessNode.ProcessNode/GetProcessInfo',
            Common__pb2.empty.SerializeToString,
            ProcessNode__pb2.return_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersionInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ProcessNode.ProcessNode/GetVersionInfo',
            Common__pb2.empty.SerializeToString,
            ProcessNode__pb2.return_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from .ZoneSenderObject import ZoneSenderObject


class DiagnosticEcuInfo(ZoneSenderObject):
    def __init__(self, ecu_name: str, channel: int, request_id: int, response_id: int, function_id: int):
        super().__init__()
        self.ecu_name = ecu_name
        self.channel = channel
        self.request_id = request_id
        self.response_id = response_id
        self.function_id = function_id

    def __str__(self):
        return f'{self.ecu_name} channel: {self.channel}, request_id: {self.request_id}, response_id: {self.response_id}, function_id: {self.function_id}'



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import Common_pb2 as Common__pb2
from . import UdsOnCanTP_pb2 as UdsOnCanTP__pb2


class UdsOnCanTPStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.subscribe = channel.unary_unary(
                '/UdsOnCanTP.UdsOnCanTP/subscribe',
                request_serializer=UdsOnCanTP__pb2.node_info.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.generate_key = channel.unary_unary(
                '/UdsOnCanTP.UdsOnCanTP/generate_key',
                request_serializer=UdsOnCanTP__pb2.request_para.SerializeToString,
                response_deserializer=UdsOnCanTP__pb2.key_value_list.FromString,
                )


class UdsOnCanTPServicer(object):
    """Missing associated documentation comment in .proto file."""

    def subscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def generate_key(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UdsOnCanTPServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'subscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.subscribe,
                    request_deserializer=UdsOnCanTP__pb2.node_info.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'generate_key': grpc.unary_unary_rpc_method_handler(
                    servicer.generate_key,
                    request_deserializer=UdsOnCanTP__pb2.request_para.FromString,
                    response_serializer=UdsOnCanTP__pb2.key_value_list.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'UdsOnCanTP.UdsOnCanTP', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UdsOnCanTP(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/UdsOnCanTP.UdsOnCanTP/subscribe',
            UdsOnCanTP__pb2.node_info.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def generate_key(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/UdsOnCanTP.UdsOnCanTP/generate_key',
            UdsOnCanTP__pb2.request_para.SerializeToString,
            UdsOnCanTP__pb2.key_value_list.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TcpIpNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fTcpIpNode.proto\x12\tTcpIpNode\x1a\x0c\x43ommon.proto\"6\n\x0fproto_port_info\x12\x11\n\tprotoName\x18\x01 \x01(\t\x12\x10\n\x08portList\x18\x02 \x03(\x04\"\x83\x01\n\x0fzone_ifcae_info\x12\x13\n\x0bnetworkName\x18\x01 \x01(\t\x12\x12\n\nswitchName\x18\x02 \x01(\t\x12\x12\n\nmacAddress\x18\x03 \x03(\x05\x12\x11\n\tipAddress\x18\x04 \x03(\x05\x12\x0f\n\x07netMask\x18\x05 \x03(\x05\x12\x0f\n\x07gateWay\x18\x06 \x03(\x05\"_\n\x10vector_port_info\x12\x13\n\x0bnetworkName\x18\x01 \x01(\t\x12\x12\n\nswitchName\x18\x02 \x01(\t\x12\x10\n\x08portName\x18\x03 \x01(\t\x12\x10\n\x08portType\x18\x04 \x01(\t\"e\n\x14vector_all_port_info\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12-\n\x08\x61ll_port\x18\x02 \x03(\x0b\x32\x1b.TcpIpNode.vector_port_info\"D\n\x0fopenPort_result\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x11\n\tportIndex\x18\x02 \x01(\x05\".\n\x0cgroupAddress\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0f\n\x07groupIp\x18\x02 \x03(\x05\x32\xc2\x05\n\tTcpIpNode\x12:\n\x0eInitTcpIpStack\x12\x16.Common.generic_string\x1a\x0e.Common.result\"\x00\x12\x32\n\x0fStartTcpIpStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12\x31\n\x0eStopTcpIpStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12H\n\x14GetAllVectorPortInfo\x12\r.Common.empty\x1a\x1f.TcpIpNode.vector_all_port_info\"\x00\x12K\n\x0eOpenVectorPort\x12\x1b.TcpIpNode.vector_port_info\x1a\x1a.TcpIpNode.openPort_result\"\x00\x12@\n\x10\x41\x64\x64ProtoPortInfo\x12\x1a.TcpIpNode.proto_port_info\x1a\x0e.Common.result\"\x00\x12J\n\x0e\x43reatZoneIface\x12\x1a.TcpIpNode.zone_ifcae_info\x1a\x1a.TcpIpNode.openPort_result\"\x00\x12\x34\n\x0bZoneIfaceUp\x12\x13.Common.generic_int\x1a\x0e.Common.result\"\x00\x12\x36\n\rZoneIfaceDown\x12\x13.Common.generic_int\x1a\x0e.Common.result\"\x00\x12\x38\n\x0fZoneIfaceRemove\x12\x13.Common.generic_int\x1a\x0e.Common.result\"\x00\x12\x45\n\x18ZoneIfaceAddGroupAddress\x12\x17.TcpIpNode.groupAddress\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_PROTO_PORT_INFO = DESCRIPTOR.message_types_by_name['proto_port_info']
_ZONE_IFCAE_INFO = DESCRIPTOR.message_types_by_name['zone_ifcae_info']
_VECTOR_PORT_INFO = DESCRIPTOR.message_types_by_name['vector_port_info']
_VECTOR_ALL_PORT_INFO = DESCRIPTOR.message_types_by_name['vector_all_port_info']
_OPENPORT_RESULT = DESCRIPTOR.message_types_by_name['openPort_result']
_GROUPADDRESS = DESCRIPTOR.message_types_by_name['groupAddress']
proto_port_info = _reflection.GeneratedProtocolMessageType('proto_port_info', (_message.Message,), {
  'DESCRIPTOR' : _PROTO_PORT_INFO,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.proto_port_info)
  })
_sym_db.RegisterMessage(proto_port_info)

zone_ifcae_info = _reflection.GeneratedProtocolMessageType('zone_ifcae_info', (_message.Message,), {
  'DESCRIPTOR' : _ZONE_IFCAE_INFO,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.zone_ifcae_info)
  })
_sym_db.RegisterMessage(zone_ifcae_info)

vector_port_info = _reflection.GeneratedProtocolMessageType('vector_port_info', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR_PORT_INFO,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.vector_port_info)
  })
_sym_db.RegisterMessage(vector_port_info)

vector_all_port_info = _reflection.GeneratedProtocolMessageType('vector_all_port_info', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR_ALL_PORT_INFO,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.vector_all_port_info)
  })
_sym_db.RegisterMessage(vector_all_port_info)

openPort_result = _reflection.GeneratedProtocolMessageType('openPort_result', (_message.Message,), {
  'DESCRIPTOR' : _OPENPORT_RESULT,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.openPort_result)
  })
_sym_db.RegisterMessage(openPort_result)

groupAddress = _reflection.GeneratedProtocolMessageType('groupAddress', (_message.Message,), {
  'DESCRIPTOR' : _GROUPADDRESS,
  '__module__' : 'TcpIpNode_pb2'
  # @@protoc_insertion_point(class_scope:TcpIpNode.groupAddress)
  })
_sym_db.RegisterMessage(groupAddress)

_TCPIPNODE = DESCRIPTOR.services_by_name['TcpIpNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROTO_PORT_INFO._serialized_start=44
  _PROTO_PORT_INFO._serialized_end=98
  _ZONE_IFCAE_INFO._serialized_start=101
  _ZONE_IFCAE_INFO._serialized_end=232
  _VECTOR_PORT_INFO._serialized_start=234
  _VECTOR_PORT_INFO._serialized_end=329
  _VECTOR_ALL_PORT_INFO._serialized_start=331
  _VECTOR_ALL_PORT_INFO._serialized_end=432
  _OPENPORT_RESULT._serialized_start=434
  _OPENPORT_RESULT._serialized_end=502
  _GROUPADDRESS._serialized_start=504
  _GROUPADDRESS._serialized_end=550
  _TCPIPNODE._serialized_start=553
  _TCPIPNODE._serialized_end=1259
# @@protoc_insertion_point(module_scope)
